// SAL_VERSION=4.1.2 XML_VERSION=5.1.0
module MTM1M3 {
struct accelerometerData_9537e860 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Accelerometer Data timestamp")
	  float	rawAccelerometer[8]; // @Metadata=(Units="unitless",Description="Accelerometer data raw Accelerometer")
	  float	accelerometer[8]; // @Metadata=(Units="unitless",Description="Accelerometer data accelerometer")
	  float	angularAccelerationX; // @Metadata=(Units="unitless",Description="Accelerometer data angular Acceleration X")
	  float	angularAccelerationY; // @Metadata=(Units="unitless",Description="Accelerometer data angular Acceleration Y")
	  float	angularAccelerationZ; // @Metadata=(Units="unitless",Description="Accelerometer data angular Acceleration Z")
	};
#pragma keylist accelerometerData_9537e860 
struct command_abort_62d3a8d0 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_abort_62d3a8d0 
struct command_abortProfile_88b2fb6a {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	abortProfile; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_abortProfile_88b2fb6a 
struct command_abortRaiseM1M3_7afaba9d {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	abortRaiseM1M3; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_abortRaiseM1M3_7afaba9d 
struct command_applyAberrationForces_4f7ead34 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces to apply in the z direction.")
	};
#pragma keylist command_applyAberrationForces_4f7ead34 
struct command_applyAberrationForcesByBendingModes_ef2ea53d {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	coefficients[22]; // @Metadata=(Units="unitless",Description="Coefficients for the bending modes.")
	};
#pragma keylist command_applyAberrationForcesByBendingModes_ef2ea53d 
struct command_applyActiveOpticForces_c79b863f {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces to apply in the z direction.")
	};
#pragma keylist command_applyActiveOpticForces_c79b863f 
struct command_applyActiveOpticForcesByBendingModes_3b76ff5b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	coefficients[22]; // @Metadata=(Units="unitless",Description="Coefficients for the bending modes.")
	};
#pragma keylist command_applyActiveOpticForcesByBendingModes_3b76ff5b 
struct command_applyOffsetForces_c715c535 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Offset to apply in the x direction.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Offset to apply in the y direction.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Offset to apply in the z direction.")
	};
#pragma keylist command_applyOffsetForces_c715c535 
struct command_applyOffsetForcesByMirrorForce_4d09c953 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	xForce; // @Metadata=(Units="N",Description="Offset to apply in the x direction.")
	  float	yForce; // @Metadata=(Units="N",Description="Offset to apply in the y direction.")
	  float	zForce; // @Metadata=(Units="N",Description="Offset to apply in the z direction.")
	  float	xMoment; // @Metadata=(Units="m",Description="Movement to apply in the x direction.")
	  float	yMoment; // @Metadata=(Units="m",Description="Movement to apply in the y direction.")
	  float	zMoment; // @Metadata=(Units="m",Description="Movement to apply in the z direction.")
	};
#pragma keylist command_applyOffsetForcesByMirrorForce_4d09c953 
struct command_clearAberrationForces_58d2b112 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	clearAberrationForces; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_clearAberrationForces_58d2b112 
struct command_clearActiveOpticForces_d4ffa42c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	clearActiveOpticForces; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_clearActiveOpticForces_d4ffa42c 
struct command_clearOffsetForces_0d7f285d {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	clearOffsetForces; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_clearOffsetForces_0d7f285d 
struct command_disable_04faa884 {  // @Metadata=(Description="Transition from state Enabled to Disabled.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_disable_04faa884 
struct command_disableHardpointChase_dbe9a16b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  short	hardpointActuator; // @Metadata=(Units="unitless",Description="ID of the actuator do disable.")
	};
#pragma keylist command_disableHardpointChase_dbe9a16b 
struct command_disableHardpointCorrections_07d1f2ea {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	disableHardpointCorrections; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_disableHardpointCorrections_07d1f2ea 
struct command_enable_c128bf47 {  // @Metadata=(Description="Transition from state Disabled to Enabled.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_enable_c128bf47 
struct command_enableHardpointChase_49c0d4e1 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  short	hardpointActuator; // @Metadata=(Units="unitless",Description="Actuator id.")
	};
#pragma keylist command_enableHardpointChase_49c0d4e1 
struct command_enableHardpointCorrections_dae9c1ec {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	enableHardpointCorrections; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_enableHardpointCorrections_dae9c1ec 
struct command_enterControl_417c941a {  // @Metadata=(Description="Transition from state Offline to Standby. Only "externally commandable" CSCs support this command; other CSCs start in Standby state and quit when they go to Offline.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_enterControl_417c941a 
struct command_enterEngineering_89e1ff1c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	enterEngineering; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_enterEngineering_89e1ff1c 
struct command_exitControl_e2ea247d {  // @Metadata=(Description="Transition from state Standby to Offline. For CSCs that are not "externally commandable" this makes the CSC quit.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_exitControl_e2ea247d 
struct command_exitEngineering_01073d21 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	exitEngineering; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_exitEngineering_01073d21 
struct command_lowerM1M3_69afda69 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	lowerM1M3; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_lowerM1M3_69afda69 
struct command_modbusTransmit_a3c81bde {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	actuatorId; // @Metadata=(Units="unitless",Description="Id of the actuator.")
	  short	functionCode; // @Metadata=(Units="unitless",Description="Code of the function to transmit.")
	  short	data[252]; // @Metadata=(Units="unitless",Description="Id of the data do transmit.")
	  short	dataLength; // @Metadata=(Units="unitless",Description="Size of the data to unpack.")
	};
#pragma keylist command_modbusTransmit_a3c81bde 
struct command_moveHardpointActuators_4d114fab {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	steps[6]; // @Metadata=(Units="unitless",Description="Steps to move hardpoints actuators.")
	};
#pragma keylist command_moveHardpointActuators_4d114fab 
struct command_positionM1M3_fa7ca786 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	xPosition; // @Metadata=(Units="m",Description="M1M3 position in the x direction.")
	  float	yPosition; // @Metadata=(Units="m",Description="M1M3 position in the y direction.")
	  float	zPosition; // @Metadata=(Units="m",Description="M1M3 position in the z direction.")
	  float	xRotation; // @Metadata=(Units="deg",Description="M1M3 rotation with respect to the x-axis.")
	  float	yRotation; // @Metadata=(Units="deg",Description="M1M3 rotation with respect to the y-axis.")
	  float	zRotation; // @Metadata=(Units="deg",Description="M1M3 rotation with respect to the z-axis.")
	};
#pragma keylist command_positionM1M3_fa7ca786 
struct command_programILC_7dde50ee {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	actuatorId; // @Metadata=(Units="unitless",Description="Id of the actuator.")
	  string<256>	filePath; // @Metadata=(Units="unitless",Description="Path to the file with ILC program.")
	};
#pragma keylist command_programILC_7dde50ee 
struct command_raiseM1M3_f0a54745 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	raiseM1M3; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	  boolean	bypassReferencePosition; // @Metadata=(Units="unitless",Description="Bypass reference position when raising M1M3?")
	};
#pragma keylist command_raiseM1M3_f0a54745 
struct command_resetPID_bc5508ce {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  short	pid; // @Metadata=(Units="unitless",Description="PID")
	};
#pragma keylist command_resetPID_bc5508ce 
struct command_runMirrorForceProfile_33f2be6c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	xForce[1000]; // @Metadata=(Units="unitless",Description="X forces profile")
	  float	yForce[1000]; // @Metadata=(Units="unitless",Description="Y forces profile")
	  float	zForce[1000]; // @Metadata=(Units="unitless",Description="Z forces profile")
	  float	xMoment[1000]; // @Metadata=(Units="unitless",Description="X forces moments")
	  float	yMoment[1000]; // @Metadata=(Units="unitless",Description="Y forces moments")
	  float	zMoment[1000]; // @Metadata=(Units="unitless",Description="Z forces moments")
	};
#pragma keylist command_runMirrorForceProfile_33f2be6c 
struct command_setLogLevel_346fd770 {  // @Metadata=(Description="Set the logging level.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	level; // @Metadata=(Units="unitless",Description="Logging level; as a Python logging level: error=40; warning=30; info=20; debug=10.")
	};
#pragma keylist command_setLogLevel_346fd770 
struct command_setSimulationMode_dccc3b3c {  // @Metadata=(Description="Set the simulation mode.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	mode; // @Metadata=(Units="unitless",Description="Desired simulation mode; 0 for normal operation (no simulation); other supported values are specific to each CSC.")
	};
#pragma keylist command_setSimulationMode_dccc3b3c 
struct command_setThermalSetpoint_ca5041e8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	setpoint; // @Metadata=(Units="unitless",Description="Temperature set point")
	};
#pragma keylist command_setThermalSetpoint_ca5041e8 
struct command_setValue_56638307 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	parametersAndValues; // @Metadata=(Units="unitless",Description="List of parameters and their values as a Json string")
	};
#pragma keylist command_setValue_56638307 
struct command_shutdown_46d06e01 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	shutdown; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_shutdown_46d06e01 
struct command_standby_9b43256c {  // @Metadata=(Description="Transition from state Offline; Disabled or Fault to Standby.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_standby_9b43256c 
struct command_start_63435b30 {  // @Metadata=(Description="Transition from state Standby to Disable; in a specified configuration.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	settingsToApply; // @Metadata=(Units="unitless",Description="Name of the selected settings set")
	};
#pragma keylist command_start_63435b30 
struct command_stopHardpointMotion_727b2152 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	stopHardpointMotion; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_stopHardpointMotion_727b2152 
struct command_testAir_37cd327c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	testAir; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_testAir_37cd327c 
struct command_testForceActuator_f1a37131 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  short	forceActuator; // @Metadata=(Units="unitless",Description="Id of the actuator to test.")
	};
#pragma keylist command_testForceActuator_f1a37131 
struct command_testHardpoint_3736f433 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  short	hardpointActuator; // @Metadata=(Units="unitless",Description="Id of the hardpoint actuator to test.")
	};
#pragma keylist command_testHardpoint_3736f433 
struct command_translateM1M3_4d0dfbfe {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	xTranslation; // @Metadata=(Units="m",Description="M1M3 translation in the x direction.")
	  float	yTranslation; // @Metadata=(Units="m",Description="M1M3 translation in the y direction.")
	  float	zTranslation; // @Metadata=(Units="m",Description="M1M3 translation in the z direction.")
	  float	xRotation; // @Metadata=(Units="deg",Description="M1M3 rotation with respect to x-axis.")
	  float	yRotation; // @Metadata=(Units="deg",Description="M1M3 rotation with respect to y-axis.")
	  float	zRotation; // @Metadata=(Units="deg",Description="M1M3 rotation with respect to z-axis.")
	};
#pragma keylist command_translateM1M3_4d0dfbfe 
struct command_turnAirOff_1054819e {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	turnAirOff; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_turnAirOff_1054819e 
struct command_turnAirOn_acc6807c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	turnAirOn; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_turnAirOn_acc6807c 
struct command_turnLightsOff_08b6e5a2 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	turnLightsOff; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_turnLightsOff_08b6e5a2 
struct command_turnLightsOn_89e80426 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	turnLightsOn; // @Metadata=(Units="unitless",Description="Dummy placeholder")
	};
#pragma keylist command_turnLightsOn_89e80426 
struct command_turnPowerOff_41dde1fd {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	turnPowerNetworkAOff; // @Metadata=(Units="unitless",Description="Turn network A power off?")
	  boolean	turnPowerNetworkBOff; // @Metadata=(Units="unitless",Description="Turn network B power off?")
	  boolean	turnPowerNetworkCOff; // @Metadata=(Units="unitless",Description="Turn network C power off?")
	  boolean	turnPowerNetworkDOff; // @Metadata=(Units="unitless",Description="Turn network D power off?")
	  boolean	turnAuxPowerNetworkAOff; // @Metadata=(Units="unitless",Description="Turn auxiliary power to network A off?")
	  boolean	turnAuxPowerNetworkBOff; // @Metadata=(Units="unitless",Description="Turn auxiliary power to network B off?")
	  boolean	turnAuxPowerNetworkCOff; // @Metadata=(Units="unitless",Description="Turn auxiliary power to network C off?")
	  boolean	turnAuxPowerNetworkDOff; // @Metadata=(Units="unitless",Description="Turn auxiliary power to network D off?")
	};
#pragma keylist command_turnPowerOff_41dde1fd 
struct command_turnPowerOn_7c3fbe06 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	turnPowerNetworkAOn; // @Metadata=(Units="unitless",Description="Turn network A power on?")
	  boolean	turnPowerNetworkBOn; // @Metadata=(Units="unitless",Description="Turn network B power on?")
	  boolean	turnPowerNetworkCOn; // @Metadata=(Units="unitless",Description="Turn network C power on?")
	  boolean	turnPowerNetworkDOn; // @Metadata=(Units="unitless",Description="Turn network D power on?")
	  boolean	turnAuxPowerNetworkAOn; // @Metadata=(Units="unitless",Description="Turn auxiliary power to network A off?")
	  boolean	turnAuxPowerNetworkBOn; // @Metadata=(Units="unitless",Description="Turn auxiliary power to network B on?")
	  boolean	turnAuxPowerNetworkCOn; // @Metadata=(Units="unitless",Description="Turn auxiliary power to network C on?")
	  boolean	turnAuxPowerNetworkDOn; // @Metadata=(Units="unitless",Description="Turn auxiliary power to network D on?")
	};
#pragma keylist command_turnPowerOn_7c3fbe06 
struct command_updatePID_6e2af9f8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  short	pid; // @Metadata=(Units="unitless",Description="PID")
	  double	timestep; // @Metadata=(Units="second",Description="Time step where correction will be applied")
	  double	p; // @Metadata=(Units="unitless",Description="Proportional coefficient value.")
	  double	i; // @Metadata=(Units="unitless",Description="Integral coefficient value.")
	  double	d; // @Metadata=(Units="unitless",Description="Derivative coefficient value.")
	  double	n; // @Metadata=(Units="unitless",Description="n")
	};
#pragma keylist command_updatePID_6e2af9f8 
struct forceActuatorData_5d276d43 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Force actuator data timestamp")
	  float	primaryCylinderForce[156]; // @Metadata=(Units="unitless",Description="Force actuator data primaryCylinderForce")
	  float	secondaryCylinderForce[112]; // @Metadata=(Units="unitless",Description="Force actuator data secondaryCylinderForce")
	  float	xForce[12]; // @Metadata=(Units="unitless",Description="Force actuator data xForce")
	  float	yForce[100]; // @Metadata=(Units="unitless",Description="Force actuator data yForce")
	  float	zForce[156]; // @Metadata=(Units="unitless",Description="Force actuator data zForce")
	  float	fx; // @Metadata=(Units="unitless",Description="Force actuator data fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Force actuator data fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Force actuator data fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Force actuator data mx")
	  float	my; // @Metadata=(Units="unitless",Description="Force actuator data my")
	  float	mz; // @Metadata=(Units="unitless",Description="Force actuator data mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Force actuator data force Magnitude")
	};
#pragma keylist forceActuatorData_5d276d43 
struct gyroData_52effcca {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Gyro Data timestamp")
	  float	angularVelocityX; // @Metadata=(Units="unitless",Description="Gyro Data angular Velocity X")
	  float	angularVelocityY; // @Metadata=(Units="unitless",Description="Gyro Data angular Velocity Y")
	  float	angularVelocityZ; // @Metadata=(Units="unitless",Description="Gyro Data angular Velocity Z")
	  short	sequenceNumber; // @Metadata=(Units="unitless",Description="Gyro Data sequence Number")
	  short	temperature; // @Metadata=(Units="unitless",Description="Gyro Data temperature")
	};
#pragma keylist gyroData_52effcca 
struct hardpointActuatorData_e4c2857f {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data timestamp")
	  long	stepsQueued[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data steps Queued")
	  short	stepsCommanded[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data steps Commanded")
	  float	measuredForce[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data measured Force")
	  long	encoder[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data encoder")
	  float	displacement[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data displacement")
	  float	fx; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data mx")
	  float	my; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data my")
	  float	mz; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data force Magnitude")
	  float	xPosition; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data x Position")
	  float	yPosition; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data y Position")
	  float	zPosition; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data z Position")
	  float	xRotation; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data x Rotation")
	  float	yRotation; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data y Rotation")
	  float	zRotation; // @Metadata=(Units="unitless",Description="Hardpoint Actuator data z Rotation")
	};
#pragma keylist hardpointActuatorData_e4c2857f 
struct hardpointMonitorData_8caedbd0 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Hardpoint Monitor Data timestamp")
	  float	breakawayLVDT[6]; // @Metadata=(Units="unitless",Description="Hardpoint Monitor Data breakaway LVDT")
	  float	displacementLVDT[6]; // @Metadata=(Units="unitless",Description="Hardpoint Monitor Data displacement LVDT")
	  float	breakawayPressure[6]; // @Metadata=(Units="unitless",Description="Hardpoint Monitor Data breakaway Pressure")
	  float	pressureSensor1[6]; // @Metadata=(Units="unitless",Description="Hardpoint Monitor Data pressure Sensor 1")
	  float	pressureSensor2[6]; // @Metadata=(Units="unitless",Description="Hardpoint Monitor Data pressure Sensor 2")
	  float	pressureSensor3[6]; // @Metadata=(Units="unitless",Description="Hardpoint Monitor Data pressure Sensor 3")
	};
#pragma keylist hardpointMonitorData_8caedbd0 
struct imsData_dd412900 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="IMS Data timestamp")
	  float	rawSensorData[8]; // @Metadata=(Units="unitless",Description="IMS Data raw Sensor Data")
	  float	xPosition; // @Metadata=(Units="unitless",Description="IMS Data x Position")
	  float	yPosition; // @Metadata=(Units="unitless",Description="IMS Data y Position")
	  float	zPosition; // @Metadata=(Units="unitless",Description="IMS Data z Position")
	  float	xRotation; // @Metadata=(Units="unitless",Description="IMS Data x Rotation")
	  float	yRotation; // @Metadata=(Units="unitless",Description="IMS Data y Rotation")
	  float	zRotation; // @Metadata=(Units="unitless",Description="IMS Data z Rotation")
	};
#pragma keylist imsData_dd412900 
struct inclinometerData_6233a3d3 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Inclinometer data timestamp")
	  float	inclinometerAngle; // @Metadata=(Units="unitless",Description="Inclinometer data inclinometer Angle")
	};
#pragma keylist inclinometerData_6233a3d3 
struct logevent_accelerometerWarning_aa15b0aa {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Accelerometer Warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Is there a warning on accelerometer?")
	  boolean	responseTimeout; // @Metadata=(Units="unitless",Description="Accelerometer Warning response Timeout")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_accelerometerWarning_aa15b0aa 
struct logevent_airSupplyStatus_da397eb1 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Air Supply Status timestamp")
	  boolean	airCommandedOn; // @Metadata=(Units="unitless",Description="Air suply was commanded to open.")
	  boolean	airCommandOutputOn; // @Metadata=(Units="unitless",Description="Air Supply Status air Command Output On")
	  boolean	airValveOpened; // @Metadata=(Units="unitless",Description="Air valve is open.")
	  boolean	airValveClosed; // @Metadata=(Units="unitless",Description="Air valve is closed.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_airSupplyStatus_da397eb1 
struct logevent_airSupplyWarning_52167fbe {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Air Supply Warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Is there a warning it the air supply?")
	  boolean	commandOutputMismatch; // @Metadata=(Units="unitless",Description="Air Supply Warning command Output Mismatch")
	  boolean	commandSensorMismatch; // @Metadata=(Units="unitless",Description="Air Supply Warning command Sensor Mismatch")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_airSupplyWarning_52167fbe 
struct logevent_appliedAberrationForces_d72ce7af {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied abberation forces timestamp")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in Z axis.")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied abberation forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied abberation forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied abberation forces my")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedAberrationForces_d72ce7af 
struct logevent_appliedAccelerationForces_e2698a2b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied acceleration forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Forces in x axis.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Forces in Y axis.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in Z axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied acceleration forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied acceleration forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied acceleration forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied acceleration forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied acceleration forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied acceleration forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedAccelerationForces_e2698a2b 
struct logevent_appliedActiveOpticForces_4f827b4b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied active optic forces timestamp")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in Z axis.")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied active optic forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied active optic forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied active optic forces my")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedActiveOpticForces_4f827b4b 
struct logevent_appliedAzimuthForces_7357e272 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied azimuth forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Forces in x-axis.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Forces in y-axis.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in z-axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied azimuth forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied azimuth forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied azimuth forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied azimuth forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied azimuth forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied azimuth forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedAzimuthForces_7357e272 
struct logevent_appliedBalanceForces_3f4cca0a {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied balance forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Force in x axis.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Force in y axis.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Force in z axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied balance forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied balance forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied balance forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied balance forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied balance forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied balance forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedBalanceForces_3f4cca0a 
struct logevent_appliedCylinderForces_b0d7e6d8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied Cylinder Forces timestamp")
	  long	secondaryCylinderForces[112]; // @Metadata=(Units="N",Description="Secondary cylinder forces.")
	  long	primaryCylinderForces[156]; // @Metadata=(Units="N",Description="Primary cylinder forces.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedCylinderForces_b0d7e6d8 
struct logevent_appliedElevationForces_fa715255 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied elevation forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Forces in x axis.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Forces in Y axis.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in Z axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied elevation forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied elevation forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied elevation forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied elevation forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied elevation forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied elevation forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedElevationForces_fa715255 
struct logevent_appliedForces_1d16999d {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Forces in x axis.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Forces in y axis.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in z axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedForces_1d16999d 
struct logevent_appliedOffsetForces_f19befd6 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied offset forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Forces in x axis.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Forces in y axis.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in z axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied offset forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied offset forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied offset forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied offset forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied offset forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied offset forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedOffsetForces_f19befd6 
struct logevent_appliedSettingsMatchStart_30ba5c59 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	appliedSettingsMatchStartIsTrue; // @Metadata=(Units="unitless",Description="True when the configuration matches the start conditions")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedSettingsMatchStart_30ba5c59 
struct logevent_appliedStaticForces_b210fd2d {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied static forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Forces in x axis.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Forces in y axis.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in z axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied static forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied static forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied static forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied static forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied static forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied static forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedStaticForces_b210fd2d 
struct logevent_appliedThermalForces_ee191da4 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied thermal forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Forces in x axis.")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Forces in y axis.")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Forces in z axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied thermal forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied thermal forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied thermal forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied thermal forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied thermal forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied thermal forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedThermalForces_ee191da4 
struct logevent_appliedVelocityForces_88f33d5e {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Applied velocity forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="N",Description="Forces in x axis.")
	  float	yForces[100]; // @Metadata=(Units="N",Description="Forces in y axis.")
	  float	zForces[156]; // @Metadata=(Units="N",Description="Forces in z axis.")
	  float	fx; // @Metadata=(Units="unitless",Description="Applied velocity forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Applied velocity forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Applied velocity forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Applied velocity forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Applied velocity forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Applied velocity forces mz")
	  float	forceMagnitude; // @Metadata=(Units="N",Description="Total force magnitude.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedVelocityForces_88f33d5e 
struct logevent_cellLightStatus_2a963d17 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Cell Light Status timestamp")
	  boolean	cellLightsCommandedOn; // @Metadata=(Units="unitless",Description="Cell lights are commanded to be ON")
	  boolean	cellLightsOutputOn; // @Metadata=(Units="unitless",Description="Cell Light Status cell Lights Output On")
	  boolean	cellLightsOn; // @Metadata=(Units="unitless",Description="At the moment are Cell lights ON?")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_cellLightStatus_2a963d17 
struct logevent_cellLightWarning_0610a3a7 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Cell Light Warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Is there any warning now?")
	  boolean	cellLightsOutputMismatch; // @Metadata=(Units="unitless",Description="Cell Light Warning cell Lights Output Mismatch")
	  boolean	cellLightsSensorMismatch; // @Metadata=(Units="unitless",Description="Cell Light Warning cell Lights Sensor Mismatch")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_cellLightWarning_0610a3a7 
struct logevent_commandRejectionWarning_2445d185 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Command Rejection Warning timestamp")
	  string<64>	command; // @Metadata=(Units="unitless",Description="Command Rejection Warning command")
	  string<128>	reason; // @Metadata=(Units="unitless",Description="Command Rejection Warning reason")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_commandRejectionWarning_2445d185 
struct logevent_detailedState_72060c57 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Detailed State timestamp")
	  long	detailedState; // @Metadata=(Units="unitless",Description="Detailed state")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_detailedState_72060c57 
	 const long detailedState_DetailedState_DetailedStates_DisabledState=1;
	 const long detailedState_DetailedState_DetailedStates_EnabledState=2;
	 const long detailedState_DetailedState_DetailedStates_FaultState=3;
	 const long detailedState_DetailedState_DetailedStates_OfflineState=4;
	 const long detailedState_DetailedState_DetailedStates_StandbyState=5;
	 const long detailedState_DetailedState_DetailedStates_ParkedState=6;
	 const long detailedState_DetailedState_DetailedStates_RaisingState=7;
	 const long detailedState_DetailedState_DetailedStates_ActiveState=8;
	 const long detailedState_DetailedState_DetailedStates_LoweringState=9;
	 const long detailedState_DetailedState_DetailedStates_EngineeringState=10;
	 const long detailedState_DetailedState_DetailedStates_ParkedEngineeringState=11;
	 const long detailedState_DetailedState_DetailedStates_RaisingEngineeringState=12;
	 const long detailedState_DetailedState_DetailedStates_ActiveEngineeringState=13;
	 const long detailedState_DetailedState_DetailedStates_LoweringEngineeringState=14;
	 const long detailedState_DetailedState_DetailedStates_LoweringFaultState=15;
	 const long detailedState_DetailedState_DetailedStates_ProfileHardpointCorrectionState=16;
	 const long MTM1M3_shared_SummaryStates_DisabledState=1;
	 const long MTM1M3_shared_SummaryStates_EnabledState=2;
	 const long MTM1M3_shared_SummaryStates_FaultState=3;
	 const long MTM1M3_shared_SummaryStates_OfflineState=4;
	 const long MTM1M3_shared_SummaryStates_StandbyState=5;
	 const long MTM1M3_shared_DetailedStates_DisabledState=1;
	 const long MTM1M3_shared_DetailedStates_EnabledState=2;
	 const long MTM1M3_shared_DetailedStates_FaultState=3;
	 const long MTM1M3_shared_DetailedStates_OfflineState=4;
	 const long MTM1M3_shared_DetailedStates_StandbyState=5;
	 const long MTM1M3_shared_DetailedStates_ParkedState=6;
	 const long MTM1M3_shared_DetailedStates_RaisingState=7;
	 const long MTM1M3_shared_DetailedStates_ActiveState=8;
	 const long MTM1M3_shared_DetailedStates_LoweringState=9;
	 const long MTM1M3_shared_DetailedStates_EngineeringState=10;
	 const long MTM1M3_shared_DetailedStates_ParkedEngineeringState=11;
	 const long MTM1M3_shared_DetailedStates_RaisingEngineeringState=12;
	 const long MTM1M3_shared_DetailedStates_ActiveEngineeringState=13;
	 const long MTM1M3_shared_DetailedStates_LoweringEngineeringState=14;
	 const long MTM1M3_shared_DetailedStates_LoweringFaultState=15;
	 const long MTM1M3_shared_DetailedStates_ProfileHardpointCorrectionState=16;
struct logevent_displacementSensorWarning_1035d8b2 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Displacement Sensor Warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Warning?")
	  boolean	sensorReportsInvalidCommand; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports Invalid Command")
	  boolean	sensorReportsCommunicationTimeoutError; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports Communication Timeout Error")
	  boolean	sensorReportsDataLengthError; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports Data Length Error")
	  boolean	sensorReportsNumberOfParametersError; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports Number Of Parameters Error")
	  boolean	sensorReportsParameterError; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports Parameter Error")
	  boolean	sensorReportsCommunicationError; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports Communication Error")
	  boolean	sensorReportsIDNumberError; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports ID Number Error")
	  boolean	sensorReportsExpansionLineError; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports Expansion Line Error")
	  boolean	sensorReportsWriteControlError; // @Metadata=(Units="unitless",Description="Displacement sensor warning sensor Reports Write Control Error")
	  boolean	responseTimeout; // @Metadata=(Units="unitless",Description="Displacement sensor warning response Timeout")
	  boolean	invalidLength; // @Metadata=(Units="unitless",Description="Displacement sensor warning invalid Length")
	  boolean	invalidResponse; // @Metadata=(Units="unitless",Description="Displacement sensor warning invalid Response")
	  boolean	unknownCommand; // @Metadata=(Units="unitless",Description="Displacement sensor warning unknown Command")
	  boolean	unknownProblem; // @Metadata=(Units="unitless",Description="Displacement sensor warning unknown Problem")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_displacementSensorWarning_1035d8b2 
struct logevent_errorCode_69e40bc4 {  // @Metadata=(Description="Output when a CSC goes into the Fault state as an explanation of the problem.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	errorCode; // @Metadata=(Units="unitless",Description="A numeric error code")
	  string	errorReport; // @Metadata=(Units="unitless",Description="An string providing detailed information about the error")
	  string	traceback; // @Metadata=(Units="unitless",Description="An optional stack trace of the error condition")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_errorCode_69e40bc4 
struct logevent_forceActuatorForceWarning_3a01ad1f {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Force Actuator Force Warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Force Actuator Force Warning any Warning")
	  boolean	anyPrimaryAxisMeasuredForceWarning; // @Metadata=(Units="unitless",Description="Force actuator force warning any Primary Axis Measured force warning")
	  boolean	primaryAxisMeasuredForceWarning[156]; // @Metadata=(Units="unitless",Description="Force actuator force warning primary Axis Measured force warning")
	  boolean	anySecondaryAxisMeasuredForceWarning; // @Metadata=(Units="unitless",Description="Force actuator force warning any Secondary Axis Measured force warning")
	  boolean	secondaryAxisMeasuredForceWarning[156]; // @Metadata=(Units="unitless",Description="Force actuator force warning secondary Axis Measured force warning")
	  boolean	anyPrimaryAxisFollowingErrorWarning; // @Metadata=(Units="unitless",Description="Force actuator force warning any Primary Axis Following Error Warning")
	  boolean	primaryAxisFollowingErrorWarning[156]; // @Metadata=(Units="unitless",Description="Force actuator force warning primary Axis Following Error Warning")
	  boolean	anySecondaryAxisFollowingErrorWarning; // @Metadata=(Units="unitless",Description="Force actuator force warning any Secondary Axis Following Error Warning")
	  boolean	secondaryAxisFollowingErrorWarning[156]; // @Metadata=(Units="unitless",Description="Force actuator force warning secondary Axis Following Error Warning")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_forceActuatorForceWarning_3a01ad1f 
struct logevent_forceActuatorInfo_d0ebe0c5 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Force Actuator timestamp")
	  short	referenceId[156]; // @Metadata=(Units="unitless",Description="Force Actuator reference id")
	  short	xDataReferenceId[12]; // @Metadata=(Units="unitless",Description="Force Actuator x Data Reference id")
	  short	yDataReferenceId[100]; // @Metadata=(Units="unitless",Description="Force Actuator y Data Reference id")
	  short	zDataReferenceId[156]; // @Metadata=(Units="unitless",Description="Force Actuator z Data Reference id")
	  short	actuatorType[156]; // @Metadata=(Units="unitless",Description="Force Actuator actuator type")
	  short	actuatorOrientation[156]; // @Metadata=(Units="unitless",Description="Force Actuator actuator orientation")
	  short	modbusSubnet[156]; // @Metadata=(Units="unitless",Description="Force Actuator modbus subnet")
	  short	modbusAddress[156]; // @Metadata=(Units="unitless",Description="Force Actuator modbus address")
	  float	xPosition[156]; // @Metadata=(Units="unitless",Description="Force Actuator x position")
	  float	yPosition[156]; // @Metadata=(Units="unitless",Description="Force Actuator y position")
	  float	zPosition[156]; // @Metadata=(Units="unitless",Description="Force Actuator z position")
	  long long	ilcUniqueId[156]; // @Metadata=(Units="unitless",Description="Force Actuator ILC unique id")
	  short	ilcApplicationType[156]; // @Metadata=(Units="unitless",Description="Force Actuator ILC application type")
	  short	networkNodeType[156]; // @Metadata=(Units="unitless",Description="Force Actuator network node type")
	  short	ilcSelectedOptions[156]; // @Metadata=(Units="unitless",Description="Force Actuator ILC selected options")
	  short	networkNodeOptions[156]; // @Metadata=(Units="unitless",Description="Force Actuator network node options")
	  short	majorRevision[156]; // @Metadata=(Units="unitless",Description="Force Actuator major revision")
	  short	minorRevision[156]; // @Metadata=(Units="unitless",Description="Force Actuator minor revision")
	  short	adcScanRate[156]; // @Metadata=(Units="unitless",Description="Force Actuator ADC scan rate")
	  float	mainPrimaryCylinderCoefficient[156]; // @Metadata=(Units="unitless",Description="Force Actuator main primary cylinder coefficient")
	  float	mainSecondaryCylinderCoefficient[156]; // @Metadata=(Units="unitless",Description="Force Actuator main secondary cylinder coefficient")
	  float	mainPrimaryCylinderLoadCellOffset[156]; // @Metadata=(Units="unitless",Description="Force Actuator main primary cylinder loadcell offset")
	  float	mainSecondaryCylinderLoadCellOffset[156]; // @Metadata=(Units="unitless",Description="Force Actuator main secondary cylinder loadcell offset")
	  float	mainPrimaryCylinderLoadCellSensitivity[156]; // @Metadata=(Units="unitless",Description="Force Actuator main primary cylinder loadcell sensitivity")
	  float	mainSecondaryCylinderLoadCellSensitivity[156]; // @Metadata=(Units="unitless",Description="Force Actuator main secondary cylinder loadcell sensitivity")
	  float	backupPrimaryCylinderCoefficient[156]; // @Metadata=(Units="unitless",Description="Force Actuator backup primary cylinder coefficient")
	  float	backupSecondaryCylinderCoefficient[156]; // @Metadata=(Units="unitless",Description="Force Actuator backup secondary cylinder coefficient")
	  float	backupPrimaryCylinderLoadCellOffset[156]; // @Metadata=(Units="unitless",Description="Force Actuator backup primary cylinder loadcell offset")
	  float	backupSecondaryCylinderLoadCellOffset[156]; // @Metadata=(Units="unitless",Description="Force Actuator backup secondary cylinder loadcell Offset")
	  float	backupPrimaryCylinderLoadCellSensitivity[156]; // @Metadata=(Units="unitless",Description="Force Actuator backup primary cylinder loadcell sensitivity")
	  float	backupSecondaryCylinderLoadCellSensitivity[156]; // @Metadata=(Units="unitless",Description="Force Actuator backup secondary cylinder loadcell sensitivity")
	  float	mezzaninePrimaryCylinderGain[156]; // @Metadata=(Units="unitless",Description="Force Actuator mezzanine Primary cylinder gain")
	  float	mezzanineSecondaryCylinderGain[156]; // @Metadata=(Units="unitless",Description="Force Actuator mezzanine Secondary cylinder gain")
	  long long	mezzanineUniqueId[156]; // @Metadata=(Units="unitless",Description="Force Actuator mezzanine Unique Id")
	  short	mezzanineFirmwareType[156]; // @Metadata=(Units="unitless",Description="Force Actuator mezzanine Firmware Type")
	  short	mezzanineMajorRevision[156]; // @Metadata=(Units="unitless",Description="Force Actuator mezzanine Major Revision")
	  short	mezzanineMinorRevision[156]; // @Metadata=(Units="unitless",Description="Force Actuator mezzanine Minor Revision")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_forceActuatorInfo_d0ebe0c5 
struct logevent_forceActuatorState_028222bb {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="ForceActuatorState timestamp")
	  short	ilcState[156]; // @Metadata=(Units="unitless",Description="ForceActuatorState ILC State")
	  boolean	slewFlag; // @Metadata=(Units="unitless",Description="slew flag set?")
	  boolean	staticForcesApplied; // @Metadata=(Units="unitless",Description="Static Forces Applied?")
	  boolean	elevationForcesApplied; // @Metadata=(Units="unitless",Description="Elevation Forces Applied?")
	  boolean	azimuthForcesApplied; // @Metadata=(Units="unitless",Description="Azimuth Forces Applied?")
	  boolean	thermalForcesApplied; // @Metadata=(Units="unitless",Description="Thermal forces applied?")
	  boolean	offsetForcesApplied; // @Metadata=(Units="unitless",Description="Offset Forces Applied?")
	  boolean	accelerationForcesApplied; // @Metadata=(Units="unitless",Description="Acceleration Forces Applied?")
	  boolean	velocityForcesApplied; // @Metadata=(Units="unitless",Description="velocity Forces Applied?")
	  boolean	activeOpticForcesApplied; // @Metadata=(Units="unitless",Description="Are the forces due to active optics applied?")
	  boolean	aberrationForcesApplied; // @Metadata=(Units="unitless",Description="Are the forces due to aberration applied?")
	  boolean	balanceForcesApplied; // @Metadata=(Units="unitless",Description="Are the balance forces applied?")
	  float	supportPercentage; // @Metadata=(Units="unitless",Description="Specify how much of the mirror weight is supported.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_forceActuatorState_028222bb 
struct logevent_forceActuatorWarning_34b69bc9 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Force actuator warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Is there a warning on the force actuator?")
	  boolean	anyMajorFault; // @Metadata=(Units="unitless",Description="Force actuator warning any Major Fault")
	  boolean	majorFault[156]; // @Metadata=(Units="unitless",Description="Force actuator warning major Fault")
	  boolean	anyMinorFault; // @Metadata=(Units="unitless",Description="Force actuator warning any Minor Fault")
	  boolean	minorFault[156]; // @Metadata=(Units="unitless",Description="Force actuator warning minor Fault")
	  boolean	anyFaultOverride; // @Metadata=(Units="unitless",Description="Force actuator warning any Fault Override")
	  boolean	faultOverride[156]; // @Metadata=(Units="unitless",Description="Force actuator warning fault Override")
	  boolean	anyMainCalibrationError; // @Metadata=(Units="unitless",Description="Force actuator warning any Main Calibration Error")
	  boolean	mainCalibrationError[156]; // @Metadata=(Units="unitless",Description="Force actuator warning main Calibration Error")
	  boolean	anyBackupCalibrationError; // @Metadata=(Units="unitless",Description="Force actuator warning any Backup Calibration Error")
	  boolean	backupCalibrationError[156]; // @Metadata=(Units="unitless",Description="Force actuator warning backup Calibration Error")
	  boolean	anyMezzanineError; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Error")
	  boolean	mezzanineError[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Error")
	  boolean	anyMezzanineBootloaderActive; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Bootloader Active")
	  boolean	mezzanineBootloaderActive[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Bootloader Active")
	  boolean	anyUniqueIdCRCError; // @Metadata=(Units="unitless",Description="Force actuator warning any Unique Id CRC Error")
	  boolean	uniqueIdCRCError[156]; // @Metadata=(Units="unitless",Description="Force actuator warning unique Id CRC Error")
	  boolean	anyApplicationTypeMismatch; // @Metadata=(Units="unitless",Description="Force actuator warning any Application Type Mismatch")
	  boolean	applicationTypeMismatch[156]; // @Metadata=(Units="unitless",Description="Force actuator warning application Type Mismatch")
	  boolean	anyApplicationMissing; // @Metadata=(Units="unitless",Description="Force actuator warning any Application Missing")
	  boolean	applicationMissing[156]; // @Metadata=(Units="unitless",Description="Force actuator warning application Missing")
	  boolean	anyApplicationCRCMismatch; // @Metadata=(Units="unitless",Description="Force actuator warning any Application CRC Mismatch")
	  boolean	applicationCRCMismatch[156]; // @Metadata=(Units="unitless",Description="Force actuator warning application CRC Mismatch")
	  boolean	anyOneWireMissing; // @Metadata=(Units="unitless",Description="Force actuator warning any OneWire Missing")
	  boolean	oneWireMissing[156]; // @Metadata=(Units="unitless",Description="Force actuator warning oneWire Missing")
	  boolean	anyOneWire1Mismatch; // @Metadata=(Units="unitless",Description="Force actuator warning any OneWire1 Mismatch")
	  boolean	oneWire1Mismatch[156]; // @Metadata=(Units="unitless",Description="Force actuator warning oneWire1 Mismatch")
	  boolean	anyOneWire2Mismatch; // @Metadata=(Units="unitless",Description="Force actuator warning any OneWire2 Mismatch")
	  boolean	oneWire2Mismatch[156]; // @Metadata=(Units="unitless",Description="Force actuator warning oneWire2 Mismatch")
	  boolean	anyWatchdogReset; // @Metadata=(Units="unitless",Description="Force actuator warning any Watchdog Reset")
	  boolean	watchdogReset[156]; // @Metadata=(Units="unitless",Description="Force actuator warning watchdog Reset")
	  boolean	anyBrownOut; // @Metadata=(Units="unitless",Description="Force actuator warning any Brownout")
	  boolean	brownOut[156]; // @Metadata=(Units="unitless",Description="Force actuator warning brownout")
	  boolean	anyEventTrapReset; // @Metadata=(Units="unitless",Description="Force actuator warning any Event Trap Reset")
	  boolean	eventTrapReset[156]; // @Metadata=(Units="unitless",Description="Force actuator warning event Trap Reset")
	  boolean	anySSRPowerFault; // @Metadata=(Units="unitless",Description="Force actuator warning any SSR Power Fault")
	  boolean	ssrPowerFault[156]; // @Metadata=(Units="unitless",Description="Force actuator warning SSR Power Fault")
	  boolean	anyAuxPowerFault; // @Metadata=(Units="unitless",Description="Force actuator warning any Aux Power Fault")
	  boolean	auxPowerFault[156]; // @Metadata=(Units="unitless",Description="Force actuator warning aux Power Fault")
	  boolean	anyMezzaninePowerFault; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Power Fault")
	  boolean	mezzaninePowerFault[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Power Fault")
	  boolean	anyMezzanineCurrentAmp1Fault; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Current Amp1 Fault")
	  boolean	mezzanineCurrentAmp1Fault[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Current Amp1 Fault")
	  boolean	anyMezzanineCurrentAmp2Fault; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Current Amp2 Fault")
	  boolean	mezzanineCurrentAmp2Fault[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Current Amp2 Fault")
	  boolean	anyMezzanineUniqueIdCRCError; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Unique Id CRC Error")
	  boolean	mezzanineUniqueIdCRCError[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanineUnique Id CRC Error")
	  boolean	anyMezzanineMainCalibrationError; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Main Calibration Error")
	  boolean	mezzanineMainCalibrationError[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Main Calibration Error")
	  boolean	anyMezzanineBackupCalibrationError; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Backup Calibration Error")
	  boolean	mezzanineBackupCalibrationError[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Backup Calibration Error")
	  boolean	anyMezzanineEventTrapReset; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Event Trap Reset")
	  boolean	mezzanineEventTrapReset[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Event Trap Reset")
	  boolean	anyMezzanineApplicationMissing; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Application Missing")
	  boolean	mezzanineApplicationMissing[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Application Missing")
	  boolean	anyMezzanineApplicationCRCMismatch; // @Metadata=(Units="unitless",Description="Force actuator warning any Mezzanine Application CRC Mismatch")
	  boolean	mezzanineApplicationCRCMismatch[156]; // @Metadata=(Units="unitless",Description="Force actuator warning mezzanine Application CRC Mismatch")
	  boolean	anyILCFault; // @Metadata=(Units="unitless",Description="Force actuator warning any ILC Fault")
	  boolean	ilcFault[156]; // @Metadata=(Units="unitless",Description="Force actuator warning ILC Fault")
	  boolean	anyBroadcastCounterWarning; // @Metadata=(Units="unitless",Description="Force actuator warning any Broadcast Counter Warning")
	  boolean	broadcastCounterWarning[156]; // @Metadata=(Units="unitless",Description="Force actuator warning broadcast Counter Warning")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_forceActuatorWarning_34b69bc9 
struct logevent_forceSetpointWarning_34a43cf6 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Force setpoint warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning Warning")
	  boolean	anySafetyLimitWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning Safety Limit Warning")
	  boolean	safetyLimitWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning safety Limit Warning")
	  boolean	xMomentWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning x Moment Warning")
	  boolean	yMomentWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning y Moment Warning")
	  boolean	zMomentWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning z Moment Warning")
	  boolean	anyNearNeighborWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning Near Neighbor Warning")
	  boolean	nearNeighborWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning near Neighbor Warning")
	  boolean	magnitudeWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning magnitude Warning")
	  boolean	anyFarNeighborWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Far Neighbor Warning")
	  boolean	farNeighborWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning far Neighbor Warning")
	  boolean	anyElevationForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Elevation Force Warning")
	  boolean	elevationForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning elevation Force Warning")
	  boolean	anyAzimuthForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Azimuth Force Warning")
	  boolean	azimuthForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning azimuth Force Warning")
	  boolean	anyThermalForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Thermal Force Warning")
	  boolean	thermalForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning thermal force warning")
	  boolean	anyBalanceForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Balance force warning")
	  boolean	balanceForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning balance force warning")
	  boolean	anyAccelerationForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Acceleration force warning")
	  boolean	accelerationForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning acceleration force warning")
	  boolean	activeOpticNetForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning active Optic Net force warning")
	  boolean	anyActiveOpticForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Active Optic force warning")
	  boolean	activeOpticForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning active Optic force warning")
	  boolean	anyStaticForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Static force warning")
	  boolean	staticForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning static force warning")
	  boolean	aberrationNetForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning aberration Net force warning")
	  boolean	anyAberrationForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Aberration force warning")
	  boolean	aberrationForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning aberration force warning")
	  boolean	anyOffsetForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Offset force warning")
	  boolean	offsetForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning offset force warning")
	  boolean	anyVelocityForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any Velocity force warning")
	  boolean	velocityForceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning velocity force warning")
	  boolean	anyForceWarning; // @Metadata=(Units="unitless",Description="Force setpoint warning any force warning")
	  boolean	forceWarning[156]; // @Metadata=(Units="unitless",Description="Force setpoint warning force Warning")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_forceSetpointWarning_34a43cf6 
struct logevent_gyroWarning_07c44e13 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Gyro warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Warning on the gyroscope?")
	  boolean	gyroXStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro X Status Warning")
	  boolean	gyroYStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Y Status Warning")
	  boolean	gyroZStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Z Status Warning")
	  boolean	sequenceNumberWarning; // @Metadata=(Units="unitless",Description="Gyro warning sequence Number Warning")
	  boolean	crcMismatchWarning; // @Metadata=(Units="unitless",Description="Gyro warning CRC Mismatch Warning")
	  boolean	invalidLengthWarning; // @Metadata=(Units="unitless",Description="Gyro warning invalid Length Warning")
	  boolean	invalidHeaderWarning; // @Metadata=(Units="unitless",Description="Gyro warning invalid Header Warning")
	  boolean	incompleteFrameWarning; // @Metadata=(Units="unitless",Description="Gyro warning incomplete Frame Warning")
	  boolean	gyroXSLDWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro X SLD Warning")
	  boolean	gyroXMODDACWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro X MODDAC Warning")
	  boolean	gyroXPhaseWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro X Phase Warning")
	  boolean	gyroXFlashWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro X Flash Warning")
	  boolean	gyroYSLDWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Y SLD Warning")
	  boolean	gyroYMODDACWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Y MODDAC Warning")
	  boolean	gyroYPhaseWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Y Phase Warning")
	  boolean	gyroYFlashWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Y Flash Warning")
	  boolean	gyroZSLDWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Z SLD Warning")
	  boolean	gyroZMODDACWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Z MODDAC Warning")
	  boolean	gyroZPhaseWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Z Phase Warning")
	  boolean	gyroZFlashWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Z Flash Warning")
	  boolean	gyroXSLDTemperatureStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro X SLD Temperature Status Warning")
	  boolean	gyroYSLDTemperatureStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Y SLD Temperature Status Warning")
	  boolean	gyroZSLDTemperatureStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Z SLD Temperature Status Warning")
	  boolean	gcbTemperatureStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning GCB Temperature Status Warning")
	  boolean	temperatureStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning temperature Status Warning")
	  boolean	gcbDSPSPIFlashStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning GCB DSP SPI Flash Status Warning")
	  boolean	gcbFPGASPIFlashStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning GCB FPGA SPI Flash Status Warning")
	  boolean	dspSPIFlashStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning DSP SPI Flash Status Warning")
	  boolean	fpgaSPIFlashStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning FPGA SPI Flash Status Warning")
	  boolean	gcb1_2VStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning GCB1_2V Status Warning")
	  boolean	gcb3_3VStatusWarning; // @Metadata=(Units="unitless",Description="Gyro Warning GCB3_3V Status")
	  boolean	gcb5VStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning GCB5V Status Warning")
	  boolean	v1_2StatusWarning; // @Metadata=(Units="unitless",Description="Gyro Warning V1_2 Status")
	  boolean	v3_3StatusWarning; // @Metadata=(Units="unitless",Description="Gyro Warning V3_3 Status")
	  boolean	v5StatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning v5 Status Warning")
	  boolean	gcbFPGAStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning GCB FPGA Status Warning")
	  boolean	fpgaStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning FPGA Status Warning")
	  boolean	hiSpeedSPORTStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning hiSpeed SPORT Status Warning")
	  boolean	auxSPORTStatusWarning; // @Metadata=(Units="unitless",Description="Gyro warning aux SPORT Status Warning")
	  boolean	sufficientSoftwareResourcesWarning; // @Metadata=(Units="unitless",Description="Gyro warning sufficient Software Resources Warning")
	  boolean	gyroEOVoltsPositiveWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro EO Volts Positive Warning")
	  boolean	gyroEOVoltsNegativeWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro EO Volts Negative Warning")
	  boolean	gyroXVoltsWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro X Volts Warning")
	  boolean	gyroYVoltsWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Y Volts Warning")
	  boolean	gyroZVoltsWarning; // @Metadata=(Units="unitless",Description="Gyro warning gyro Z Volts Warning")
	  boolean	gcbADCCommsWarning; // @Metadata=(Units="unitless",Description="Gyro warning GCBADC Comms Warning")
	  boolean	mSYNCExternalTimingWarning; // @Metadata=(Units="unitless",Description="Gyro warning mSYNC External Timing Warning")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_gyroWarning_07c44e13 
struct logevent_hardpointActuatorInfo_d713e706 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Hardpoint Actuator timestamp")
	  short	referenceId[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator reference Id")
	  long	referencePosition[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator reference Position")
	  short	modbusSubnet[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator modbus Subnet")
	  short	modbusAddress[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator modbus Address")
	  float	xPosition[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator x Position")
	  float	yPosition[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator y Position")
	  float	zPosition[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator z Position")
	  long long	ilcUniqueId[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator ILCUniqueId")
	  short	ilcApplicationType[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator ILC Application Type")
	  short	networkNodeType[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator network Node Type")
	  short	ilcSelectedOptions[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator ILC Selected Options")
	  short	networkNodeOptions[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator network Node Options")
	  short	majorRevision[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator major Revision")
	  short	minorRevision[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator minor Revision")
	  short	adcScanRate[6]; // @Metadata=(Units="unitless",Description="HardpointActuator ADC Scan Rate")
	  float	mainLoadCellCoefficient[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator main LoadCell Coefficient")
	  float	mainLoadCellOffset[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator main LoadCell Offset")
	  float	mainLoadCellSensitivity[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator main LoadCell Sensitivity")
	  float	backupLoadCellCoefficient[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator backup LoadCell Coefficient")
	  float	backupLoadCellOffset[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator backup LoadCell Offset")
	  float	backupLoadCellSensitivity[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator backup LoadCell Sensitivity")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_hardpointActuatorInfo_d713e706 
struct logevent_hardpointActuatorState_dfd8f788 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="HardpointActuatorState timestamp")
	  short	ilcState[6]; // @Metadata=(Units="unitless",Description="HardpointActuatorState ILC State")
	  short	motionState[6]; // @Metadata=(Units="unitless",Description="Hardpoint Actuator State motion State")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_hardpointActuatorState_dfd8f788 
struct logevent_hardpointActuatorWarning_dcc7d946 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Hardpoint Actuator Warning any Warning")
	  boolean	anyMajorFault; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Major Fault")
	  boolean	majorFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning major Fault")
	  boolean	anyMinorFault; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Minor Fault")
	  boolean	minorFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning minor Fault")
	  boolean	anyFaultOverride; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Fault Override")
	  boolean	faultOverride[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning fault Override")
	  boolean	anyMainCalibrationError; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Main Calibration Error")
	  boolean	mainCalibrationError[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning main Calibration Error")
	  boolean	anyBackupCalibrationError; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Backup Calibration Error")
	  boolean	backupCalibrationError[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning backup Calibration Error")
	  boolean	anyLimitSwitch1Operated; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Limit Switch1 Operated")
	  boolean	limitSwitch1Operated[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning limit Switch1 Operated")
	  boolean	anyLimitSwitch2Operated; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Limit Switch2 Operated")
	  boolean	limitSwitch2Operated[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning limit Switch2 Operated")
	  boolean	anyUniqueIdCRCError; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Unique Id CRC Error")
	  boolean	uniqueIdCRCError[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning unique Id CRC Error")
	  boolean	anyApplicationTypeMismatch; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Application Type Mismatch")
	  boolean	applicationTypeMismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning application Type Mismatch")
	  boolean	anyApplicationMissing; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Application Missing")
	  boolean	applicationMissing[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning application Missing")
	  boolean	anyApplicationCRCMismatch; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Application CRC Mismatch")
	  boolean	applicationCRCMismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning application CRC Mismatch")
	  boolean	anyOneWireMissing; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any OneWire Missing")
	  boolean	oneWireMissing[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning oneWire Missing")
	  boolean	anyOneWire1Mismatch; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any OneWire1 Mismatch")
	  boolean	oneWire1Mismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning oneWire1 Mismatch")
	  boolean	anyOneWire2Mismatch; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any OneWire2 Mismatch")
	  boolean	oneWire2Mismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning oneWire2 Mismatch")
	  boolean	anyWatchdogReset; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Watchdog Reset")
	  boolean	watchdogReset[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning watchdog Reset")
	  boolean	anyBrownOut; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Brownout")
	  boolean	brownOut[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning brownout")
	  boolean	anyEventTrapReset; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Event Trap Reset")
	  boolean	eventTrapReset[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning event Trap Reset")
	  boolean	anyMotorDriverFault; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Motor Driver Fault")
	  boolean	motorDriverFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning motor Driver Fault")
	  boolean	anySSRPowerFault; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any SSR Power Fault")
	  boolean	ssrPowerFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning SSR Power Fault")
	  boolean	anyAuxPowerFault; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Aux Power Fault")
	  boolean	auxPowerFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning aux Power Fault")
	  boolean	anySMCPowerFault; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any SMC Power Fault")
	  boolean	smcPowerFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning SMC Power Fault")
	  boolean	anyILCFault; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any ILC Fault")
	  boolean	ilcFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning ILC Fault")
	  boolean	anyBroadcastCounterWarning; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning any Broadcast Counter Warning")
	  boolean	broadcastCounterWarning[6]; // @Metadata=(Units="unitless",Description="Hardpoint actuator warning broadcast Counter Warning")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_hardpointActuatorWarning_dcc7d946 
struct logevent_hardpointMonitorInfo_5dc92c27 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Hardpoint Monitor timestamp")
	  short	referenceId[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor reference Id")
	  short	modbusSubnet[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor modbus Subnet")
	  short	modbusAddress[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor modbus Address")
	  long long	ilcUniqueId[6]; // @Metadata=(Units="unitless",Description="Hardpoint Monitor ILC Unique Id")
	  short	ilcApplicationType[6]; // @Metadata=(Units="unitless",Description="Hardpoint Monitor ILC Application Type")
	  short	networkNodeType[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor network Node Type")
	  short	majorRevision[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor major Revision")
	  short	minorRevision[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor minor Revision")
	  long long	mezzanineUniqueId[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor mezzanine Unique Id")
	  short	mezzanineFirmwareType[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor mezzanine Firmware Type")
	  short	mezzanineMajorRevision[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor mezzanine Major Revision")
	  short	mezzanineMinorRevision[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor mezzanine Minor Revision")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_hardpointMonitorInfo_5dc92c27 
struct logevent_hardpointMonitorState_0dad41d1 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="HardpointMonitorState timestamp")
	  short	ilcState[6]; // @Metadata=(Units="unitless",Description="HardpointMonitorState ILC State")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_hardpointMonitorState_0dad41d1 
struct logevent_hardpointMonitorWarning_d5ab85e8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Hardpoint Monitor Warning any Warning")
	  boolean	anyMajorFault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Major Fault")
	  boolean	majorFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning major Fault")
	  boolean	anyMinorFault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Minor Fault")
	  boolean	minorFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning minor Fault")
	  boolean	anyFaultOverride; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Fault Override")
	  boolean	faultOverride[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning fault Override")
	  boolean	anyInstrumentError; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Instrument Error")
	  boolean	instrumentError[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning instrument Error")
	  boolean	anyMezzanineError; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine Error")
	  boolean	mezzanineError[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine Error")
	  boolean	anyMezzanineBootloaderActive; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine Bootloader Active")
	  boolean	mezzanineBootloaderActive[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine Bootloader Active")
	  boolean	anyUniqueIdCRCError; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Unique Id CRC Error")
	  boolean	uniqueIdCRCError[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning unique Id CRC Error")
	  boolean	anyApplicationTypeMismatch; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Application Type Mismatch")
	  boolean	applicationTypeMismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning application Type Mismatch")
	  boolean	anyApplicationMissing; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Application Missing")
	  boolean	applicationMissing[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning application Missing")
	  boolean	anyApplicationCRCMismatch; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Application CRC Mismatch")
	  boolean	applicationCRCMismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning application CRC Mismatch")
	  boolean	anyOneWireMissing; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any OneWire Missing")
	  boolean	oneWireMissing[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning oneWire Missing")
	  boolean	anyOneWire1Mismatch; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any OneWire1 Mismatch")
	  boolean	oneWire1Mismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning oneWire1 Mismatch")
	  boolean	anyOneWire2Mismatch; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any OneWire2 Mismatch")
	  boolean	oneWire2Mismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning oneWire2 Mismatch")
	  boolean	anyWatchdogReset; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Watchdog Reset")
	  boolean	watchdogReset[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning watchdog Reset")
	  boolean	anyBrownOut; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Brownout")
	  boolean	brownOut[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning brownout")
	  boolean	anyEventTrapReset; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Event Trap Reset")
	  boolean	eventTrapReset[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning event Trap Reset")
	  boolean	anySSRPowerFault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any SSR Power Fault")
	  boolean	ssrPowerFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning SSR Power Fault")
	  boolean	anyAuxPowerFault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Aux Power Fault")
	  boolean	auxPowerFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning aux Power Fault")
	  boolean	anyMezzanineS1AInterface1Fault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine S1A Interface1 Fault")
	  boolean	mezzanineS1AInterface1Fault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine S1A Interface1 Fault")
	  boolean	anyMezzanineS1ALVDT1Fault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine S1A LVDT1 Fault")
	  boolean	mezzanineS1ALVDT1Fault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine S1A LVDT1 Fault")
	  boolean	anyMezzanineS1AInterface2Fault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine S1A Interface2 Fault")
	  boolean	mezzanineS1AInterface2Fault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine S1A Interface2 Fault")
	  boolean	anyMezzanineS1ALVDT2Fault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine S1A LVDT2 Fault")
	  boolean	mezzanineS1ALVDT2Fault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine S1A LVDT2 Fault")
	  boolean	anyMezzanineUniqueIdCRCError; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine Unique Id CRC Error")
	  boolean	mezzanineUniqueIdCRCError[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanineUnique Id CRC Error")
	  boolean	anyMezzanineEventTrapReset; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine Event Trap Reset")
	  boolean	mezzanineEventTrapReset[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine Event Trap Reset")
	  boolean	anyMezzanineDCPRS422ChipFault; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine DCPRS422 Chip Fault")
	  boolean	mezzanineDCPRS422ChipFault[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine DCPRS422 Chip Fault")
	  boolean	anyMezzanineApplicationMissing; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine Application Missing")
	  boolean	mezzanineApplicationMissing[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine Application Missing")
	  boolean	anyMezzanineApplicationCRCMismatch; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning any Mezzanine Application CRC Mismatch")
	  boolean	mezzanineApplicationCRCMismatch[6]; // @Metadata=(Units="unitless",Description="Hardpoint monitor warning mezzanine Application CRC Mismatch")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_hardpointMonitorWarning_d5ab85e8 
struct logevent_heartbeat_85347670 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	heartbeat; // @Metadata=(Units="unitless",Description="Beats the drum.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_heartbeat_85347670 
struct logevent_ilcWarning_22b9286f {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="ilcWarning timestamp")
	  long	actuatorId; // @Metadata=(Units="unitless",Description="ilcWarning actuator Id")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="ilcWarning warning")
	  boolean	responseTimeout; // @Metadata=(Units="unitless",Description="ILCWarning response Timeout")
	  boolean	invalidCRC; // @Metadata=(Units="unitless",Description="ILCWarning invalid CRC")
	  boolean	illegalFunction; // @Metadata=(Units="unitless",Description="ILCWarning illegal Function")
	  boolean	illegalDataValue; // @Metadata=(Units="unitless",Description="ILCWarning illegal Data Value")
	  boolean	invalidLength; // @Metadata=(Units="unitless",Description="ILCWarning invalid Length")
	  boolean	unknownSubnet; // @Metadata=(Units="unitless",Description="ILCWarning unknown Subnet")
	  boolean	unknownAddress; // @Metadata=(Units="unitless",Description="ILCWarning unknown Address")
	  boolean	unknownFunction; // @Metadata=(Units="unitless",Description="ILCWarning unknown Function")
	  boolean	unknownProblem; // @Metadata=(Units="unitless",Description="ILCWarning unknown Problem")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_ilcWarning_22b9286f 
struct logevent_inclinometerSensorWarning_4d115eb8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Inclinometer Sensor Warning any Warning")
	  boolean	sensorReportsIllegalFunction; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning sensor Reports Illegal Function")
	  boolean	sensorReportsIllegalDataAddress; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning sensor Reports Illegal Data Address")
	  boolean	responseTimeout; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning response Timeout")
	  boolean	invalidCRC; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning invalid CRC")
	  boolean	invalidLength; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning invalid Length")
	  boolean	unknownAddress; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning unknown Address")
	  boolean	unknownFunction; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning unknown Function")
	  boolean	unknownProblem; // @Metadata=(Units="unitless",Description="Inclinometer sensor warning unknown Problem")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_inclinometerSensorWarning_4d115eb8 
struct logevent_interlockStatus_5c0ae7f7 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Interlock Status timestamp")
	  boolean	heartbeatCommandedState; // @Metadata=(Units="unitless",Description="Interlock Status heartbeat Commanded State")
	  boolean	heartbeatOutputState; // @Metadata=(Units="unitless",Description="Interlock Status heartbeat Output State")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_interlockStatus_5c0ae7f7 
struct logevent_interlockWarning_bc69e2ea {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="InterlockWarning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="Interlock Warning any Warning")
	  boolean	heartbeatStateOutputMismatch; // @Metadata=(Units="unitless",Description="Interlock Warning heartbeat State Output Mismatch")
	  boolean	auxPowerNetworksOff; // @Metadata=(Units="unitless",Description="Interlock Warning aux Power Networks Off")
	  boolean	thermalEquipmentOff; // @Metadata=(Units="unitless",Description="Interlock Warning thermal Equipment Off")
	  boolean	airSupplyOff; // @Metadata=(Units="unitless",Description="Interlock Warning air Supply Off")
	  boolean	tmaMotionStop; // @Metadata=(Units="unitless",Description="Interlock Warning TMA Motion Stop")
	  boolean	gisHeartbeatLost; // @Metadata=(Units="unitless",Description="Interlock Warning GIS Heartbeat Lost")
	  boolean	cabinetDoorOpen; // @Metadata=(Units="unitless",Description="Interlock Warning cabinet Door Open")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_interlockWarning_bc69e2ea 
struct logevent_logLevel_83d14d18 {  // @Metadata=(Description="Current logging level.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	level; // @Metadata=(Units="unitless",Description="Current logging level; a Python logging level: error=40; warning=30; info=20; debug=10.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_logLevel_83d14d18 
struct logevent_logMessage_a20c3b05 {  // @Metadata=(Description="A log message.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	name; // @Metadata=(Units="unitless",Description="Log name.")
	  long	level; // @Metadata=(Units="unitless",Description="Message level; a Python logging level: error=40; warning=30; info=20; debug=10.")
	  string	message; // @Metadata=(Units="unitless",Description="Log message.")
	  string	traceback; // @Metadata=(Units="unitless",Description="Exception traceback; "" if not an exception.")
	  string	filePath; // @Metadata=(Units="unitless",Description="Path to source file.")
	  string	functionName; // @Metadata=(Units="unitless",Description="Function or method name.")
	  long	lineNumber; // @Metadata=(Units="unitless",Description="Line number in the file specified by filePath.")
	  long	process; // @Metadata=(Units="unitless",Description="Process ID.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_logMessage_a20c3b05 
struct logevent_modbusResponse_9c022b06 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Modbus Response timestamp")
	  boolean	responseValid; // @Metadata=(Units="unitless",Description="Modbus Response response Valid")
	  short	address; // @Metadata=(Units="unitless",Description="Modbus Response address")
	  short	functionCode; // @Metadata=(Units="unitless",Description="Modbus Response function Code")
	  short	dataLength; // @Metadata=(Units="unitless",Description="Modbus Response data Length")
	  short	data[252]; // @Metadata=(Units="unitless",Description="Modbus Response data")
	  unsigned short	crc; // @Metadata=(Units="unitless",Description="Modbus Response CRC")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_modbusResponse_9c022b06 
struct logevent_pidInfo_858eca99 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="PIDInfo timestamp")
	  double	timestep[6]; // @Metadata=(Units="unitless",Description="PIDInfo timestep")
	  double	p[6]; // @Metadata=(Units="unitless",Description="PIDInfo p")
	  double	i[6]; // @Metadata=(Units="unitless",Description="PIDInfo i")
	  double	d[6]; // @Metadata=(Units="unitless",Description="PIDInfo d")
	  double	n[6]; // @Metadata=(Units="unitless",Description="PIDInfo n")
	  double	calculatedA[6]; // @Metadata=(Units="unitless",Description="PIDInfo calculated A")
	  double	calculatedB[6]; // @Metadata=(Units="unitless",Description="PIDInfo calculated B")
	  double	calculatedC[6]; // @Metadata=(Units="unitless",Description="PIDInfo calculated C")
	  double	calculatedD[6]; // @Metadata=(Units="unitless",Description="PIDInfo calculated D")
	  double	calculatedE[6]; // @Metadata=(Units="unitless",Description="PIDInfo calculated E")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_pidInfo_858eca99 
struct logevent_powerStatus_846d5845 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Power Status timestamp")
	  boolean	powerNetworkACommandedOn; // @Metadata=(Units="unitless",Description="PowerStatus power Network A Commanded On")
	  boolean	powerNetworkAOutputOn; // @Metadata=(Units="unitless",Description="Power Status power Network A Output On")
	  boolean	powerNetworkBCommandedOn; // @Metadata=(Units="unitless",Description="PowerStatus power Network B Commanded On")
	  boolean	powerNetworkBOutputOn; // @Metadata=(Units="unitless",Description="Power Status power Network B Output On")
	  boolean	powerNetworkCCommandedOn; // @Metadata=(Units="unitless",Description="PowerStatus power Network C Commanded On")
	  boolean	powerNetworkCOutputOn; // @Metadata=(Units="unitless",Description="Power Status power Network C Output On")
	  boolean	powerNetworkDCommandedOn; // @Metadata=(Units="unitless",Description="PowerStatus power Network D Commanded On")
	  boolean	powerNetworkDOutputOn; // @Metadata=(Units="unitless",Description="Power Status power Network D Output On")
	  boolean	auxPowerNetworkACommandedOn; // @Metadata=(Units="unitless",Description="PowerStatus aux PowerNetwork AC ommanded On")
	  boolean	auxPowerNetworkAOutputOn; // @Metadata=(Units="unitless",Description="Power Status aux Power Network A Output On")
	  boolean	auxPowerNetworkBCommandedOn; // @Metadata=(Units="unitless",Description="PowerStatus aux PowerNetwork B Commanded On")
	  boolean	auxPowerNetworkBOutputOn; // @Metadata=(Units="unitless",Description="Power Status aux Power Network B Output On")
	  boolean	auxPowerNetworkCCommandedOn; // @Metadata=(Units="unitless",Description="PowerStatus aux PowerNetwork C Commanded On")
	  boolean	auxPowerNetworkCOutputOn; // @Metadata=(Units="unitless",Description="Power Status aux Power Network C Output On")
	  boolean	auxPowerNetworkDCommandedOn; // @Metadata=(Units="unitless",Description="PowerStatus aux PowerNetwork D Commanded On")
	  boolean	auxPowerNetworkDOutputOn; // @Metadata=(Units="unitless",Description="Power Status aux Power Network D Output On")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_powerStatus_846d5845 
struct logevent_powerSupplyStatus_9f37ac09 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Power Supply Status timestamp")
	  boolean	rcpMirrorCellUtility220VAC1Status; // @Metadata=(Units="unitless",Description="Power supply status RCP Mirror Cell Utility 220VAC1 Status")
	  boolean	rcpCabinetUtility220VACStatus; // @Metadata=(Units="unitless",Description="Power supply status RCP Cabinet Utility 220VAC Status")
	  boolean	rcpExternalEquipment220VACStatus; // @Metadata=(Units="unitless",Description="Power supply status RCP External Equipment 220VAC Status")
	  boolean	rcpMirrorCellUtility220VAC2Status; // @Metadata=(Units="unitless",Description="Power supply status RCP Mirror Cell Utility 220VAC2 Status")
	  boolean	rcpMirrorCellUtility220VAC3Status; // @Metadata=(Units="unitless",Description="Power supply status RCP Mirror Cell Utility 220VAC3 Status")
	  boolean	powerNetworkARedundancyControlStatus; // @Metadata=(Units="unitless",Description="Power supply status Network A Redundancy Control Status")
	  boolean	powerNetworkBRedundancyControlStatus; // @Metadata=(Units="unitless",Description="Power supply status Network B Redundancy Control Status")
	  boolean	powerNetworkCRedundancyControlStatus; // @Metadata=(Units="unitless",Description="Power supply status Network C Redundancy Control Status")
	  boolean	powerNetworkDRedundancyControlStatus; // @Metadata=(Units="unitless",Description="Power supply status Network D Redundancy Control Status")
	  boolean	controlsPowerNetworkRedundancyControlStatus; // @Metadata=(Units="unitless",Description="Power supply status control Power Network Redundancy Control Status")
	  boolean	powerNetworkAStatus; // @Metadata=(Units="unitless",Description="Power supply status power Network A Status")
	  boolean	powerNetworkARedundantStatus; // @Metadata=(Units="unitless",Description="Power supply status power Network A Redundant Status")
	  boolean	powerNetworkBStatus; // @Metadata=(Units="unitless",Description="Power supply status power Network B Status")
	  boolean	powerNetworkBRedundantStatus; // @Metadata=(Units="unitless",Description="Power supply status power Network B Redundant Status")
	  boolean	powerNetworkCStatus; // @Metadata=(Units="unitless",Description="Power supply status power Network C Status")
	  boolean	powerNetworkCRedundantStatus; // @Metadata=(Units="unitless",Description="Power supply status power Network C Redundant Status")
	  boolean	powerNetworkDStatus; // @Metadata=(Units="unitless",Description="Power supply status power Network D Status")
	  boolean	powerNetworkDRedundantStatus; // @Metadata=(Units="unitless",Description="Power supply status power Network D Redundant Status")
	  boolean	controlsPowerNetworkStatus; // @Metadata=(Units="unitless",Description="Power supply status controls Power Network Status")
	  boolean	controlsPowerNetworkRedundantStatus; // @Metadata=(Units="unitless",Description="Power supply status controls Power Network Redundant Status")
	  boolean	lightPowerNetworkStatus; // @Metadata=(Units="unitless",Description="Power supply status light Power Network Status")
	  boolean	externalEquipmentPowerNetworkStatus; // @Metadata=(Units="unitless",Description="Power supply status external Equipment Power Network Status")
	  boolean	laserTrackerPowerNetworkStatus; // @Metadata=(Units="unitless",Description="Power supply status laser Tracker Power Network Status")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_powerSupplyStatus_9f37ac09 
struct logevent_powerWarning_cedc8628 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Power Warning timestamp")
	  boolean	anyWarning; // @Metadata=(Units="unitless",Description="PowerWarning any Warning")
	  boolean	powerNetworkAOutputMismatch; // @Metadata=(Units="unitless",Description="Power Warning power Network A Output Mismatch")
	  boolean	powerNetworkBOutputMismatch; // @Metadata=(Units="unitless",Description="Power Warning power Network B Output Mismatch")
	  boolean	powerNetworkCOutputMismatch; // @Metadata=(Units="unitless",Description="Power Warning power Network C Output Mismatch")
	  boolean	powerNetworkDOutputMismatch; // @Metadata=(Units="unitless",Description="Power Warning power Network D Output Mismatch")
	  boolean	auxPowerNetworkAOutputMismatch; // @Metadata=(Units="unitless",Description="Power Warning aux Power Network A Output Mismatch")
	  boolean	auxPowerNetworkBOutputMismatch; // @Metadata=(Units="unitless",Description="Power Warning aux Power Network B Output Mismatch")
	  boolean	auxPowerNetworkCOutputMismatch; // @Metadata=(Units="unitless",Description="Power Warning aux Power Network C Output Mismatch")
	  boolean	auxPowerNetworkDOutputMismatch; // @Metadata=(Units="unitless",Description="Power Warning aux Power Network D Output Mismatch")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_powerWarning_cedc8628 
struct logevent_rejectedAberrationForces_07bb7050 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected aberration forces timestamp")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Aberration Forces z Forces")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected aberration forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected aberration forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected aberration forces my")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedAberrationForces_07bb7050 
struct logevent_rejectedAccelerationForces_b8520238 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected acceleration forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Acceleration Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected AccelerationForces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected AccelerationForces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected acceleration forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected acceleration forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected acceleration forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected acceleration forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected acceleration forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected acceleration forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Acceleration Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedAccelerationForces_b8520238 
struct logevent_rejectedActiveOpticForces_b308b353 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected active optic forces timestamp")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Active Optic Forces z Forces")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected active optic forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected active optic forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected active optic forces my")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedActiveOpticForces_b308b353 
struct logevent_rejectedAzimuthForces_e69b5c03 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected azimuth forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Azimuth Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected Azimuth Forces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Azimuth Forces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected azimuth forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected azimuth forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected azimuth forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected azimuth forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected azimuth forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected azimuth forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Azimuth Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedAzimuthForces_e69b5c03 
struct logevent_rejectedBalanceForces_3d81e3db {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected balance forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Balance Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected Balance Forces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Balance forces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected balance forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected balance forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected balance forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected balance forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected balance forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected balance forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Balance Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedBalanceForces_3d81e3db 
struct logevent_rejectedCylinderForces_f4002407 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected Cylinder Forces timestamp")
	  long	secondaryCylinderForces[112]; // @Metadata=(Units="unitless",Description="Rejected secondary Cylinder Forces")
	  long	primaryCylinderForces[156]; // @Metadata=(Units="unitless",Description="Rejected primary Cylinder Forces")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedCylinderForces_f4002407 
struct logevent_rejectedElevationForces_bf1221a9 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected elevation forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Elevation Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected Elevation Forces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Elevation Forces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected elevation forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected elevation forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected elevation forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected elevation forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected elevation forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected elevation forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Elevation Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedElevationForces_bf1221a9 
struct logevent_rejectedForces_7969f67b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected Forces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Forces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedForces_7969f67b 
struct logevent_rejectedOffsetForces_9ae34670 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected offset forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Offset Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected Offset Forces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Offset Forces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected offset forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected offset forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected offset forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected offset forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected offset forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected offset forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Offset Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedOffsetForces_9ae34670 
struct logevent_rejectedStaticForces_95f4fc51 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected static forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Static Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected Static Forces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Static Forces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected static forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected static forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected static forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected static forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected static forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected static forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Static Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedStaticForces_95f4fc51 
struct logevent_rejectedThermalForces_bda7bbdd {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected thermal forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Thermal Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected Thermal Forces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Thermal Forces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected thermal forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected thermal forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected thermal forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected thermal forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected thermal forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected thermal forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Thermal Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedThermalForces_bda7bbdd 
struct logevent_rejectedVelocityForces_9e4d8b9f {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Rejected velocity forces timestamp")
	  float	xForces[12]; // @Metadata=(Units="unitless",Description="Rejected Velocity Forces x Forces")
	  float	yForces[100]; // @Metadata=(Units="unitless",Description="Rejected Velocity Forces y Forces")
	  float	zForces[156]; // @Metadata=(Units="unitless",Description="Rejected Velocity Forces z Forces")
	  float	fx; // @Metadata=(Units="unitless",Description="Rejected velocity forces fx")
	  float	fy; // @Metadata=(Units="unitless",Description="Rejected velocity forces fy")
	  float	fz; // @Metadata=(Units="unitless",Description="Rejected velocity forces fz")
	  float	mx; // @Metadata=(Units="unitless",Description="Rejected velocity forces mx")
	  float	my; // @Metadata=(Units="unitless",Description="Rejected velocity forces my")
	  float	mz; // @Metadata=(Units="unitless",Description="Rejected velocity forces mz")
	  float	forceMagnitude; // @Metadata=(Units="unitless",Description="Rejected Velocity Forces force Magnitude")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_rejectedVelocityForces_9e4d8b9f 
struct logevent_settingVersions_69930df7 {  // @Metadata=(Description="Information about settings which can be specified in the start command.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	recommendedSettingsVersion; // @Metadata=(Units="unitless",Description="List of comma seperated recomended versions of settings sets")
	  string	recommendedSettingsLabels; // @Metadata=(Units="unitless",Description="List of comma seperated names of settings sets")
	  string	settingsUrl; // @Metadata=(Units="unitless",Description="The URL where the settings sets definitions can be found")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_settingVersions_69930df7 
struct logevent_settingsApplied_61b4dd6e {  // @Metadata=(Description="Base settings applied.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	settingsVersion; // @Metadata=(Units="unitless",Description="The SHA or name corresponding to the published configuration")
	  string	otherSettingsEvents; // @Metadata=(Units="unitless",Description="A comma delimited list of other specific CSC configuration events. This may be blank if no other CSC specific events are necessary")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_settingsApplied_61b4dd6e 
struct logevent_simulationMode_a613ee19 {  // @Metadata=(Description="Current simulation mode.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	mode; // @Metadata=(Units="unitless",Description="Current simulation mode; 0 for normal operation (no simulation); other supported values are specific to each CSC.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_simulationMode_a613ee19 
struct logevent_softwareVersions_ed013250 {  // @Metadata=(Description="Current verions of software in use by CSC.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<16>	salVersion; // @Metadata=(Units="unitless",Description="This is the current version of SAL generation")
	  string<16>	xmlVersion; // @Metadata=(Units="unitless",Description="This is the current version of CSC XML")
	  string<16>	openSpliceVersion; // @Metadata=(Units="unitless",Description="This is the current version of OpenSplice")
	  string<16>	cscVersion; // @Metadata=(Units="unitless",Description="This is the top-level version of the CSC")
	  string	subsystemVersions; // @Metadata=(Units="unitless",Description="A comma delimited list of key=value pairs relating subsystem name (key) to its version number (value). This may be left blank if there are no subsystems within a CSC")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_softwareVersions_ed013250 
struct logevent_summaryState_ccb8e0c3 {  // @Metadata=(Description="Current summary state of the CSC")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	summaryState; // @Metadata=(Units="unitless",Description="High level state machine state identifier")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_summaryState_ccb8e0c3 
struct outerLoopData_0cb4c7ed {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Outer Loop Data timestamp")
	  short	broadcastCounter; // @Metadata=(Units="unitless",Description="Outer Loop Data broadcast Counter")
	  boolean	slewFlag; // @Metadata=(Units="unitless",Description="Outer Loop Data slew Flag")
	  double	executionTime; // @Metadata=(Units="unitless",Description="Outer Loop Data execution Time")
	};
#pragma keylist outerLoopData_0cb4c7ed 
struct pidData_0bd588ed {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="PID Data timestamp")
	  double	setpoint[6]; // @Metadata=(Units="unitless",Description="PID Data setpoint")
	  double	measuredPID[6]; // @Metadata=(Units="unitless",Description="PIDData measurement")
	  double	error[6]; // @Metadata=(Units="unitless",Description="PID Data error")
	  double	errorT1[6]; // @Metadata=(Units="unitless",Description="PID Data error T1")
	  double	errorT2[6]; // @Metadata=(Units="unitless",Description="PID Data error T2")
	  double	control[6]; // @Metadata=(Units="unitless",Description="PID Data control")
	  double	controlT1[6]; // @Metadata=(Units="unitless",Description="PID Data control T1")
	  double	controlT2[6]; // @Metadata=(Units="unitless",Description="PID Data control T2")
	};
#pragma keylist pidData_0bd588ed 
struct powerSupplyData_daf67bc2 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  double	timestamp; // @Metadata=(Units="unitless",Description="Power Supply Data timestamp")
	  float	powerNetworkACurrent; // @Metadata=(Units="unitless",Description="Power Supply Data Network A Current")
	  float	powerNetworkBCurrent; // @Metadata=(Units="unitless",Description="Power Supply Data Network B Current")
	  float	powerNetworkCCurrent; // @Metadata=(Units="unitless",Description="Power Supply Data Network C Current")
	  float	powerNetworkDCurrent; // @Metadata=(Units="unitless",Description="Power Supply Data Network D Current")
	  float	lightPowerNetworkCurrent; // @Metadata=(Units="unitless",Description="Power Supply Data light Power Network Current")
	  float	controlsPowerNetworkCurrent; // @Metadata=(Units="unitless",Description="Power Supply Data controls Power Network Current")
	};
#pragma keylist powerSupplyData_daf67bc2 
struct ackcmd_004df1cb {  // @Metadata=(Description="")
      string<8>	private_revCode;
      double		private_sndStamp;
      double		private_rcvStamp;
      long		private_origin;
      long 		private_host;
      long		private_seqNum;
      long 		ack;
      long 		error;
      string<256>	result;
      long		host;
      long		origin;
      long		cmdtype;
      double		timeout;
	};
#pragma keylist ackcmd_004df1cb 
};

